import { Buff } from '@cmdcode/buff';
import { SignerAPI } from '@cmdcode/signer';
import { EventEmitter } from '../class/emitter.js';
import { NostrSocket } from '../class/socket.js';
import { EventFilter, SignedEvent, SocketConfig, StoreConfig, StoreItem } from '../types.js';
export declare class NostrStore<T extends Record<string, any>> extends EventEmitter<{
    'close': NostrStore<T>;
    'error': [error: unknown, data: unknown];
    'fetch': NostrStore<T>;
    'ready': NostrStore<T>;
    'reject': [reason: string, event: SignedEvent];
    'update': NostrStore<T>;
}> {
    static list: typeof fetch_stores;
    readonly _filter: EventFilter;
    readonly _opt: StoreConfig<T>;
    readonly _secret: Buff;
    readonly _signer: SignerAPI;
    _buffer?: ReturnType<typeof setTimeout>;
    _data: T | null;
    _init: boolean;
    _prev: T | null;
    _socket: NostrSocket | null;
    _updated: number | null;
    constructor(secret: string, signer: SignerAPI, config?: Partial<StoreConfig<T>>);
    get data(): T;
    get filter(): EventFilter;
    get hash(): string;
    get id(): string;
    get pubkey(): string;
    get ready(): boolean;
    get secret(): string;
    get socket(): NostrSocket;
    get store(): Map<string, any>;
    get updated_at(): number;
    log: {
        debug: (...s: unknown[]) => void | null;
        info: (...s: unknown[]) => void | null;
    };
    _bounce_handler(reason: string, event: SignedEvent): void;
    _event_filter(event: SignedEvent): boolean;
    _event_handler(event: SignedEvent): void;
    _err_handler(err: unknown, data: unknown): void;
    _fetch(): Promise<void>;
    _send(data: unknown, tags: string[][], updated: number): Promise<this>;
    _update(data: T, tags: string[][], updated: number): Promise<this>;
    connect(address: string, opt?: Partial<SocketConfig>): Promise<void>;
    close(): this;
    delete(): void;
    fetch(): Promise<this>;
    init(address: string, store: T, opt?: Partial<SocketConfig>): this;
    refresh(): Promise<this>;
    toString(): string;
    toJSON(): T;
    update(data: T, tags?: string[][], updated_at?: number): Promise<this>;
    [Symbol.iterator](): IterableIterator<[string, any]>;
}
declare function fetch_stores(address: string, signer: SignerAPI, filter?: EventFilter, options?: Partial<SocketConfig>): Promise<StoreItem[]>;
export {};
